@@ -36,31 +36,31 @@
 
 //#include <streams.h>
 
-#include "ebml/MemReadIOCallback.h"
-#include "ebml/SafeReadIOCallback.h"
+#include <ebml/MemReadIOCallback.h>
+#include <ebml/SafeReadIOCallback.h>
 #include "matroska/KaxBlock.h"
 #include "matroska/KaxContexts.h"
 #include "matroska/KaxBlockData.h"
 #include "matroska/KaxCluster.h"
 #include "matroska/KaxDefines.h"
 
-START_LIBMATROSKA_NAMESPACE
+namespace libmatroska {
 
 DataBuffer * DataBuffer::Clone()
 {
-  binary *ClonedData = (binary *)malloc(mySize * sizeof(binary));
-  assert(ClonedData != NULL);
+  auto ClonedData = static_cast<binary *>(malloc(mySize * sizeof(binary)));
+  assert(ClonedData != nullptr);
   memcpy(ClonedData, myBuffer ,mySize );
 
-  SimpleDataBuffer * result = new SimpleDataBuffer(ClonedData, mySize, 0);
+  auto result = new SimpleDataBuffer(ClonedData, mySize, 0);
   result->bValidValue = bValidValue;
   return result;
 }
 
 SimpleDataBuffer::SimpleDataBuffer(const SimpleDataBuffer & ToClone)
-  :DataBuffer((binary *)malloc(ToClone.mySize * sizeof(binary)), ToClone.mySize, myFreeBuffer)
+  :DataBuffer(static_cast<binary *>(malloc(ToClone.mySize * sizeof(binary))), ToClone.mySize, myFreeBuffer)
 {
-  assert(myBuffer != NULL);
+  assert(myBuffer != nullptr);
   memcpy(myBuffer, ToClone.myBuffer ,mySize );
   bValidValue = ToClone.bValidValue;
 }
@@ -85,24 +85,22 @@ KaxInternalBlock::KaxInternalBlock(const KaxInternalBlock & ElementToClone)
   ,ParentCluster(ElementToClone.ParentCluster) ///< \todo not exactly
 {
   // add a clone of the list
-  std::vector<DataBuffer *>::const_iterator Itr = ElementToClone.myBuffers.begin();
-  std::vector<DataBuffer *>::iterator myItr = myBuffers.begin();
+  auto Itr = ElementToClone.myBuffers.begin();
+  auto myItr = myBuffers.begin();
   while (Itr != ElementToClone.myBuffers.end()) {
     *myItr = (*Itr)->Clone();
-    Itr++; myItr++;
+    ++Itr; ++myItr;
   }
 }
 
 
-KaxBlockGroup::~KaxBlockGroup()
+/* KaxBlockGroup::~KaxBlockGroup()
 {
   //NOTE("KaxBlockGroup::~KaxBlockGroup");
-}
+} */
 
 KaxBlockGroup::KaxBlockGroup(EBML_EXTRA_DEF)
   :EbmlMaster(EBML_CLASS_SEMCONTEXT(KaxBlockGroup) EBML_DEF_SEP EBML_EXTRA_CALL)
-  ,ParentCluster(NULL)
-  ,ParentTrack(NULL)
 {}
 
 /*!
@@ -113,10 +111,10 @@ KaxBlockGroup::KaxBlockGroup(EBML_EXTRA_DEF)
 bool KaxInternalBlock::AddFrame(const KaxTrackEntry & track, uint64 timecode, DataBuffer & buffer, LacingType lacing, bool invisible)
 {
   SetValueIsSet();
-  if (myBuffers.size() == 0) {
+  if (myBuffers.empty()) {
     // first frame
     Timecode = timecode;
-    TrackNumber = track.TrackNumber();
+    TrackNumber = static_cast<uint64>(track.TrackNumber());
     mInvisible = invisible;
     mLacing = lacing;
   }
@@ -131,8 +129,8 @@ bool KaxInternalBlock::AddFrame(const KaxTrackEntry & track, uint64 timecode, Da
     // a frame in a lace is not efficient when the place necessary to code it in a lace is bigger
     // than the size of a simple Block. That means more than 6 bytes (4 in struct + 2 for EBML) to code the size
     return (buffer.Size() < 6*0xFF);
-  else
-    return true;
+
+  return true;
 }
 
 /*!
@@ -147,26 +145,26 @@ LacingType KaxInternalBlock::GetBestLacingType() const {
 
   XiphLacingSize = 1; // Number of laces is stored in 1 byte.
   EbmlLacingSize = 1;
-  for (i = 0; i < (int)myBuffers.size() - 1; i++) {
+  for (i = 0; i < static_cast<int>(myBuffers.size()) - 1; i++) {
     if (myBuffers[i]->Size() != myBuffers[i + 1]->Size())
       SameSize = false;
     XiphLacingSize += myBuffers[i]->Size() / 255 + 1;
   }
   EbmlLacingSize += CodedSizeLength(myBuffers[0]->Size(), 0, IsFiniteSize());
-  for (i = 1; i < (int)myBuffers.size() - 1; i++)
-    EbmlLacingSize += CodedSizeLengthSigned(int64(myBuffers[i]->Size()) - int64(myBuffers[i - 1]->Size()), 0);
+  for (i = 1; i < static_cast<int>(myBuffers.size()) - 1; i++)
+    EbmlLacingSize += CodedSizeLengthSigned(static_cast<int64>(myBuffers[i]->Size()) - static_cast<int64>(myBuffers[i - 1]->Size()), 0);
   if (SameSize)
     return LACING_FIXED;
-  else if (XiphLacingSize < EbmlLacingSize)
+  if (XiphLacingSize < EbmlLacingSize)
     return LACING_XIPH;
-  else
-    return LACING_EBML;
+
+  return LACING_EBML;
 }
 
 filepos_t KaxInternalBlock::UpdateSize(bool /* bSaveDefault */, bool /* bForceRender */)
 {
   LacingType LacingHere;
-  assert(EbmlBinary::GetBuffer() == NULL); // Data is not used for KaxInternalBlock
+  assert(EbmlBinary::GetBuffer() == nullptr); // Data is not used for KaxInternalBlock
   assert(TrackNumber < 0x4000); // no more allowed for the moment
   unsigned int i;
 
@@ -193,7 +191,7 @@ filepos_t KaxInternalBlock::UpdateSize(bool /* bSaveDefault */, bool /* bForceRe
         case LACING_EBML:
           SetSize_(GetSize() + myBuffers[0]->Size() + CodedSizeLength(myBuffers[0]->Size(), 0, IsFiniteSize()));
           for (i=1; i<myBuffers.size()-1; i++) {
-            SetSize_(GetSize() + myBuffers[i]->Size() + CodedSizeLengthSigned(int64(myBuffers[i]->Size()) - int64(myBuffers[i-1]->Size()), 0));
+            SetSize_(GetSize() + myBuffers[i]->Size() + CodedSizeLengthSigned(static_cast<int64>(myBuffers[i]->Size()) - static_cast<int64>(myBuffers[i-1]->Size()), 0));
           }
           break;
         case LACING_FIXED:
@@ -216,7 +214,6 @@ filepos_t KaxInternalBlock::UpdateSize(bool /* bSaveDefault */, bool /* bForceRe
   return GetSize();
 }
 
-#if MATROSKA_VERSION >= 2
 KaxBlockVirtual::KaxBlockVirtual(const KaxBlockVirtual & ElementToClone)
   :EbmlBinary(ElementToClone)
   ,Timecode(ElementToClone.Timecode)
@@ -228,7 +225,6 @@ KaxBlockVirtual::KaxBlockVirtual(const KaxBlockVirtual & ElementToClone)
 }
 
 KaxBlockVirtual::KaxBlockVirtual(EBML_EXTRA_DEF)
-  :EBML_DEF_BINARY(KaxBlockVirtual)EBML_DEF_SEP ParentCluster(NULL)
 {
   SetBuffer(DataBlock,sizeof(DataBlock));
   SetValueIsSet(false);
@@ -237,7 +233,7 @@ KaxBlockVirtual::KaxBlockVirtual(EBML_EXTRA_DEF)
 KaxBlockVirtual::~KaxBlockVirtual()
 {
   if(GetBuffer() == DataBlock)
-    SetBuffer( NULL, 0 );
+    SetBuffer( nullptr, 0 );
 }
 
 filepos_t KaxBlockVirtual::UpdateSize(bool /* bSaveDefault */, bool /* bForceRender */)
@@ -254,9 +250,9 @@ filepos_t KaxBlockVirtual::UpdateSize(bool /* bSaveDefault */, bool /* bForceRen
     *cursor++ = TrackNumber & 0xFF;
   }
 
-  assert(ParentCluster != NULL);
-  int16 ActualTimecode = ParentCluster->GetBlockLocalTimecode(Timecode);
-  big_int16 b16(ActualTimecode);
+  assert(ParentCluster != nullptr);
+  const int16 ActualTimecode = ParentCluster->GetBlockLocalTimecode(Timecode);
+  const auto b16 = big_int16(ActualTimecode);
   b16.Fill(cursor);
   cursor += 2;
 
@@ -264,7 +260,6 @@ filepos_t KaxBlockVirtual::UpdateSize(bool /* bSaveDefault */, bool /* bForceRen
 
   return GetSize();
 }
-#endif // MATROSKA_VERSION
 
 /*!
   \todo more optimisation is possible (render the Block head and don't copy the buffer in memory, care should be taken with the allocation of Data)
@@ -272,7 +267,7 @@ filepos_t KaxBlockVirtual::UpdateSize(bool /* bSaveDefault */, bool /* bForceRen
 */
 filepos_t KaxInternalBlock::RenderData(IOCallback & output, bool /* bForceRender */, bool /* bSaveDefault */)
 {
-  if (myBuffers.size() == 0) {
+  if (myBuffers.empty()) {
     return 0;
   } else {
     assert(TrackNumber < 0x4000);
@@ -287,7 +282,7 @@ filepos_t KaxInternalBlock::RenderData(IOCallback & output, bool /* bForceRender
         mLacing = LACING_EBML; // supposedly the best of all
       SetSize_(4 + 1); // 1 for the lacing head (number of laced elements)
     }
-    if (TrackNumber > 0x80)
+    if (TrackNumber >= 0x80)
       SetSize_(GetSize() + 1);
 
     // write Block Head
@@ -298,9 +293,9 @@ filepos_t KaxInternalBlock::RenderData(IOCallback & output, bool /* bForceRender
       *cursor++ = TrackNumber & 0xFF;
     }
 
-    assert(ParentCluster != NULL);
-    int16 ActualTimecode = ParentCluster->GetBlockLocalTimecode(Timecode);
-    big_int16 b16(ActualTimecode);
+    assert(ParentCluster != nullptr);
+    const int16 ActualTimecode = ParentCluster->GetBlockLocalTimecode(Timecode);
+    const auto b16 = big_int16(ActualTimecode);
     b16.Fill(cursor);
     cursor += 2;
 
@@ -338,7 +333,7 @@ filepos_t KaxInternalBlock::RenderData(IOCallback & output, bool /* bForceRender
         assert(0);
     }
 
-    output.writeFully(BlockHead, 4 + ((TrackNumber > 0x80) ? 1 : 0));
+    output.writeFully(BlockHead, 4 + ((TrackNumber >= 0x80) ? 1 : 0));
 
     binary tmpValue;
     switch (mLacing) {
@@ -356,7 +351,7 @@ filepos_t KaxInternalBlock::RenderData(IOCallback & output, bool /* bForceRender
             SetSize_(GetSize() + 1);
             tmpSize -= 0xFF;
           }
-          tmpValue = binary(tmpSize);
+          tmpValue = static_cast<binary>(tmpSize);
           output.writeFully(&tmpValue, 1);
           SetSize_(GetSize() + 1);
         }
@@ -381,7 +376,7 @@ filepos_t KaxInternalBlock::RenderData(IOCallback & output, bool /* bForceRender
 
           // set the size of each member in the lace
           for (i=1; i<myBuffers.size()-1; i++) {
-            _Size = int64(myBuffers[i]->Size()) - int64(myBuffers[i-1]->Size());
+            _Size = static_cast<int64>(myBuffers[i]->Size()) - static_cast<int64>(myBuffers[i-1]->Size());
             _CodedSize = CodedSizeLengthSigned(_Size, 0);
             CodedValueLengthSigned(_Size, _CodedSize, _FinalHead);
             output.writeFully(_FinalHead, _CodedSize);
@@ -435,8 +430,8 @@ uint64 KaxInternalBlock::ReadInternalHead(IOCallback & input)
 
   big_int16 b16;
   b16.Eval(cursor);
-  assert(ParentCluster != NULL);
-  Timecode = ParentCluster->GetBlockGlobalTimecode(int16(b16));
+  assert(ParentCluster != nullptr);
+  Timecode = ParentCluster->GetBlockGlobalTimecode(static_cast<int16>(b16));
   bLocalTimecodeUsed = false;
   cursor += 2;
 
@@ -460,7 +455,7 @@ filepos_t KaxInternalBlock::ReadData(IOCallback & input, ScopeMode ReadFully)
       if (Result != GetSize())
         throw SafeReadIOCallback::EndOfStreamX(GetSize() - Result);
 
-      binary *BufferStart = EbmlBinary::GetBuffer();
+      binary *const BufferStart = EbmlBinary::GetBuffer();
 
       SafeReadIOCallback Mem(*this);
       uint8 BlockHeadSize = 4;
@@ -480,28 +475,28 @@ filepos_t KaxInternalBlock::ReadData(IOCallback & input, ScopeMode ReadFully)
         TrackNumber &= 0x7F;
       }
 
-      LocalTimecode = int16(Mem.GetUInt16BE());
+      LocalTimecode = static_cast<int16>(Mem.GetUInt16BE());
       bLocalTimecodeUsed = true;
 
-      uint8 Flags = Mem.GetUInt8();
+      const uint8 Flags = Mem.GetUInt8();
       if (EbmlId(*this) == EBML_ID(KaxSimpleBlock)) {
         bIsKeyframe = (Flags & 0x80) != 0;
         bIsDiscardable = (Flags & 0x01) != 0;
       }
       mInvisible = (Flags & 0x08) >> 3;
-      mLacing = LacingType((Flags & 0x06) >> 1);
+      mLacing = static_cast<LacingType>((Flags & 0x06) >> 1);
 
       // put all Frames in the list
       if (mLacing == LACING_NONE) {
         FirstFrameLocation += Mem.GetPosition();
-        DataBuffer * soloFrame = new DataBuffer(BufferStart + Mem.GetPosition(), GetSize() - BlockHeadSize);
+        auto soloFrame = new DataBuffer(BufferStart + Mem.GetPosition(), GetSize() - BlockHeadSize);
         myBuffers.push_back(soloFrame);
         SizeList.resize(1);
         SizeList[0] = GetSize() - BlockHeadSize;
       } else {
         // read the number of frames in the lace
         uint32 LastBufferSize = GetSize() - BlockHeadSize - 1; // 1 for number of frame
-        uint8 FrameNum = Mem.GetUInt8(); // number of frames in the lace - 1
+        const uint8 FrameNum = Mem.GetUInt8(); // number of frames in the lace - 1
         // read the list of frame sizes
         uint8 Index;
         int32 FrameSize;
@@ -529,6 +524,8 @@ filepos_t KaxInternalBlock::ReadData(IOCallback & input, ScopeMode ReadFully)
           case LACING_EBML:
             SizeRead = LastBufferSize;
             FrameSize = ReadCodedSizeValue(BufferStart + Mem.GetPosition(), SizeRead, SizeUnknown);
+            if (!FrameSize || (static_cast<uint32>(FrameSize + SizeRead) > LastBufferSize))
+              throw SafeReadIOCallback::EndOfStreamX(SizeRead);
             SizeList[0] = FrameSize;
             Mem.Skip(SizeRead);
             LastBufferSize -= FrameSize + SizeRead;
@@ -537,6 +534,8 @@ filepos_t KaxInternalBlock::ReadData(IOCallback & input, ScopeMode ReadFully)
               // get the size of the frame
               SizeRead = LastBufferSize;
               FrameSize += ReadCodedSizeSignedValue(BufferStart + Mem.GetPosition(), SizeRead, SizeUnknown);
+              if (!FrameSize || (static_cast<uint32>(FrameSize + SizeRead) > LastBufferSize))
+                throw SafeReadIOCallback::EndOfStreamX(SizeRead);
               SizeList[Index] = FrameSize;
               Mem.Skip(SizeRead);
               LastBufferSize -= FrameSize + SizeRead;
@@ -557,20 +556,20 @@ filepos_t KaxInternalBlock::ReadData(IOCallback & input, ScopeMode ReadFully)
         FirstFrameLocation += Mem.GetPosition();
 
         for (Index=0; Index<=FrameNum; Index++) {
-          DataBuffer * lacedFrame = new DataBuffer(BufferStart + Mem.GetPosition(), SizeList[Index]);
+          auto lacedFrame = new DataBuffer(BufferStart + Mem.GetPosition(), SizeList[Index]);
           myBuffers.push_back(lacedFrame);
           Mem.Skip(SizeList[Index]);
         }
       }
 
-      binary *BufferEnd = BufferStart + GetSize();
-      size_t NumFrames  = myBuffers.size();
+      binary *const BufferEnd = BufferStart + GetSize();
+      const size_t NumFrames  = myBuffers.size();
 
       // Sanity checks for frame pointers and boundaries.
       for (size_t Index = 0; Index < NumFrames; ++Index) {
-        binary *FrameStart  = myBuffers[Index]->Buffer();
-        binary *FrameEnd    = FrameStart + myBuffers[Index]->Size();
-        binary *ExpectedEnd = (Index + 1) < NumFrames ? myBuffers[Index + 1]->Buffer() : BufferEnd;
+        binary *const FrameStart  = myBuffers[Index]->Buffer();
+        binary *const FrameEnd    = FrameStart + myBuffers[Index]->Size();
+        binary *const ExpectedEnd = (Index + 1) < NumFrames ? myBuffers[Index + 1]->Buffer() : BufferEnd;
 
         if ((FrameStart < BufferStart) || (FrameEnd > BufferEnd) || (FrameEnd != ExpectedEnd))
           throw SafeReadIOCallback::EndOfStreamX(0);
@@ -603,7 +602,7 @@ filepos_t KaxInternalBlock::ReadData(IOCallback & input, ScopeMode ReadFully)
 
       big_int16 b16;
       b16.Eval(cursor);
-      LocalTimecode = int16(b16);
+      LocalTimecode = static_cast<int16>(b16);
       bLocalTimecodeUsed = true;
       cursor += 2;
 
@@ -612,7 +611,7 @@ filepos_t KaxInternalBlock::ReadData(IOCallback & input, ScopeMode ReadFully)
         bIsDiscardable = (*cursor & 0x01) != 0;
       }
       mInvisible = (*cursor & 0x08) >> 3;
-      mLacing = LacingType((*cursor++ & 0x06) >> 1);
+      mLacing = static_cast<LacingType>((*cursor++ & 0x06) >> 1);
       if (cursor == &_TempHead[4]) {
         _TempHead[0] = _TempHead[4];
       } else {
@@ -624,11 +623,12 @@ filepos_t KaxInternalBlock::ReadData(IOCallback & input, ScopeMode ReadFully)
       // put all Frames in the list
       if (mLacing != LACING_NONE) {
         // read the number of frames in the lace
-        uint32 LastBufferSize = GetSize() - BlockHeadSize - 1; // 1 for number of frame
-        uint8 FrameNum = _TempHead[0]; // number of frames in the lace - 1
+        const uint32 TotalLacedSize = GetSize() - BlockHeadSize - 1; // 1 for number of frame
+        uint32 LastBufferSize = TotalLacedSize;
+        const uint8 FrameNum = _TempHead[0]; // number of frames in the lace - 1
         // read the list of frame sizes
         uint8 Index;
-        int32 FrameSize;
+        uint32 FrameSize;
         uint32 SizeRead;
         uint64 SizeUnknown;
 
@@ -641,7 +641,9 @@ filepos_t KaxInternalBlock::ReadData(IOCallback & input, ScopeMode ReadFully)
               FrameSize = 0;
               do {
                 Result += input.read(_TempHead, 1);
-                FrameSize += uint8(_TempHead[0]);
+                FrameSize += static_cast<uint8>(_TempHead[0]);
+                if (FrameSize > TotalLacedSize)
+                  throw SafeReadIOCallback::EndOfStreamX(0);
                 LastBufferSize--;
 
                 FirstFrameLocation++;
@@ -658,6 +660,8 @@ filepos_t KaxInternalBlock::ReadData(IOCallback & input, ScopeMode ReadFully)
             cursor = _tmpBuf = new binary[FrameNum*4]; /// \warning assume the mean size will be coded in less than 4 bytes
             Result += input.read(cursor, FrameNum*4);
             FrameSize = ReadCodedSizeValue(cursor, SizeRead, SizeUnknown);
+            if (FrameSize > TotalLacedSize)
+              throw SafeReadIOCallback::EndOfStreamX(0);
             SizeList[0] = FrameSize;
             cursor += SizeRead;
             LastBufferSize -= FrameSize + SizeRead;
@@ -666,6 +670,8 @@ filepos_t KaxInternalBlock::ReadData(IOCallback & input, ScopeMode ReadFully)
               // get the size of the frame
               SizeRead = LastBufferSize;
               FrameSize += ReadCodedSizeSignedValue(cursor, SizeRead, SizeUnknown);
+              if (FrameSize > TotalLacedSize)
+                throw SafeReadIOCallback::EndOfStreamX(0);
               SizeList[Index] = FrameSize;
               cursor += SizeRead;
               LastBufferSize -= FrameSize + SizeRead;
@@ -699,7 +705,6 @@ filepos_t KaxInternalBlock::ReadData(IOCallback & input, ScopeMode ReadFully)
   } catch (SafeReadIOCallback::EndOfStreamX &) {
     SetValueIsSet(false);
 
-    std::memset(EbmlBinary::GetBuffer(), 0, GetSize());
     myBuffers.clear();
     SizeList.clear();
     Timecode           = 0;
@@ -716,8 +721,8 @@ filepos_t KaxInternalBlock::ReadData(IOCallback & input, ScopeMode ReadFully)
 
 bool KaxBlockGroup::AddFrame(const KaxTrackEntry & track, uint64 timecode, DataBuffer & buffer, LacingType lacing)
 {
-  KaxBlock & theBlock = GetChild<KaxBlock>(*this);
-  assert(ParentCluster != NULL);
+  auto & theBlock = GetChild<KaxBlock>(*this);
+  assert(ParentCluster != nullptr);
   theBlock.SetParent(*ParentCluster);
   ParentTrack = &track;
   return theBlock.AddFrame(track, timecode, buffer, lacing);
@@ -727,13 +732,13 @@ bool KaxBlockGroup::AddFrame(const KaxTrackEntry & track, uint64 timecode, DataB
 {
   //  assert(past_timecode < 0);
 
-  KaxBlock & theBlock = GetChild<KaxBlock>(*this);
-  assert(ParentCluster != NULL);
+  auto & theBlock = GetChild<KaxBlock>(*this);
+  assert(ParentCluster != nullptr);
   theBlock.SetParent(*ParentCluster);
   ParentTrack = &track;
-  bool bRes = theBlock.AddFrame(track, timecode, buffer, lacing);
+  const bool bRes = theBlock.AddFrame(track, timecode, buffer, lacing);
 
-  KaxReferenceBlock & thePastRef = GetChild<KaxReferenceBlock>(*this);
+  auto & thePastRef = GetChild<KaxReferenceBlock>(*this);
   thePastRef.SetReferencedBlock(PastBlock);
   thePastRef.SetParentBlock(*this);
 
@@ -746,17 +751,17 @@ bool KaxBlockGroup::AddFrame(const KaxTrackEntry & track, uint64 timecode, DataB
 
   //  assert(forw_timecode > 0);
 
-  KaxBlock & theBlock = GetChild<KaxBlock>(*this);
-  assert(ParentCluster != NULL);
+  auto & theBlock = GetChild<KaxBlock>(*this);
+  assert(ParentCluster != nullptr);
   theBlock.SetParent(*ParentCluster);
   ParentTrack = &track;
-  bool bRes = theBlock.AddFrame(track, timecode, buffer, lacing);
+  bool const bRes = theBlock.AddFrame(track, timecode, buffer, lacing);
 
-  KaxReferenceBlock & thePastRef = GetChild<KaxReferenceBlock>(*this);
+  auto & thePastRef = GetChild<KaxReferenceBlock>(*this);
   thePastRef.SetReferencedBlock(PastBlock);
   thePastRef.SetParentBlock(*this);
 
-  KaxReferenceBlock & theFutureRef = AddNewChild<KaxReferenceBlock>(*this);
+  auto & theFutureRef = AddNewChild<KaxReferenceBlock>(*this);
   theFutureRef.SetReferencedBlock(ForwBlock);
   theFutureRef.SetParentBlock(*this);
 
@@ -765,20 +770,20 @@ bool KaxBlockGroup::AddFrame(const KaxTrackEntry & track, uint64 timecode, DataB
 
 bool KaxBlockGroup::AddFrame(const KaxTrackEntry & track, uint64 timecode, DataBuffer & buffer, const KaxBlockBlob * PastBlock, const KaxBlockBlob * ForwBlock, LacingType lacing)
 {
-  KaxBlock & theBlock = GetChild<KaxBlock>(*this);
-  assert(ParentCluster != NULL);
+  auto & theBlock = GetChild<KaxBlock>(*this);
+  assert(ParentCluster != nullptr);
   theBlock.SetParent(*ParentCluster);
   ParentTrack = &track;
-  bool bRes = theBlock.AddFrame(track, timecode, buffer, lacing);
+  const bool bRes = theBlock.AddFrame(track, timecode, buffer, lacing);
 
-  if (PastBlock != NULL) {
-    KaxReferenceBlock & thePastRef = GetChild<KaxReferenceBlock>(*this);
+  if (PastBlock != nullptr) {
+    auto & thePastRef = GetChild<KaxReferenceBlock>(*this);
     thePastRef.SetReferencedBlock(PastBlock);
     thePastRef.SetParentBlock(*this);
   }
 
-  if (ForwBlock != NULL) {
-    KaxReferenceBlock & theFutureRef = AddNewChild<KaxReferenceBlock>(*this);
+  if (ForwBlock != nullptr) {
+    auto & theFutureRef = AddNewChild<KaxReferenceBlock>(*this);
     theFutureRef.SetReferencedBlock(ForwBlock);
     theFutureRef.SetParentBlock(*this);
   }
@@ -791,37 +796,36 @@ bool KaxBlockGroup::AddFrame(const KaxTrackEntry & track, uint64 timecode, DataB
 */
 uint64 KaxBlockGroup::GlobalTimecode() const
 {
-  assert(ParentCluster != NULL); // impossible otherwise
-  KaxInternalBlock & MyBlock = *static_cast<KaxBlock *>(this->FindElt(EBML_INFO(KaxBlock)));
-  return MyBlock.GlobalTimecode();
-
+  assert(ParentCluster != nullptr); // impossible otherwise
+  auto MyBlock = static_cast<KaxBlock *>(this->FindElt(EBML_INFO(KaxBlock)));
+  return MyBlock->GlobalTimecode();
 }
 
 uint16 KaxBlockGroup::TrackNumber() const
 {
-  KaxInternalBlock & MyBlock = *static_cast<KaxBlock *>(this->FindElt(EBML_INFO(KaxBlock)));
-  return MyBlock.TrackNum();
+  auto MyBlock = static_cast<KaxBlock *>(this->FindElt(EBML_INFO(KaxBlock)));
+  return MyBlock->TrackNum();
 }
 
 uint64 KaxBlockGroup::ClusterPosition() const
 {
-  assert(ParentCluster != NULL); // impossible otherwise
+  assert(ParentCluster != nullptr); // impossible otherwise
   return ParentCluster->GetPosition();
 }
 
 uint64 KaxInternalBlock::ClusterPosition() const
 {
-  assert(ParentCluster != NULL); // impossible otherwise
+  assert(ParentCluster != nullptr); // impossible otherwise
   return ParentCluster->GetPosition();
 }
 
 unsigned int KaxBlockGroup::ReferenceCount() const
 {
   unsigned int Result = 0;
-  KaxReferenceBlock * MyBlockAdds = static_cast<KaxReferenceBlock *>(FindFirstElt(EBML_INFO(KaxReferenceBlock)));
-  if (MyBlockAdds != NULL) {
+  auto MyBlockAdds = static_cast<KaxReferenceBlock *>(FindFirstElt(EBML_INFO(KaxReferenceBlock)));
+  if (MyBlockAdds != nullptr) {
     Result++;
-    while ((MyBlockAdds = static_cast<KaxReferenceBlock *>(FindNextElt(*MyBlockAdds))) != NULL) {
+    while ((MyBlockAdds = static_cast<KaxReferenceBlock *>(FindNextElt(*MyBlockAdds))) != nullptr) {
       Result++;
     }
   }
@@ -830,12 +834,12 @@ unsigned int KaxBlockGroup::ReferenceCount() const
 
 const KaxReferenceBlock & KaxBlockGroup::Reference(unsigned int Index) const
 {
-  KaxReferenceBlock * MyBlockAdds = static_cast<KaxReferenceBlock *>(FindFirstElt(EBML_INFO(KaxReferenceBlock)));
-  assert(MyBlockAdds != NULL); // call of a non existing reference
+  auto MyBlockAdds = static_cast<KaxReferenceBlock *>(FindFirstElt(EBML_INFO(KaxReferenceBlock)));
+  assert(MyBlockAdds != nullptr); // call of a non existing reference
 
   while (Index != 0) {
     MyBlockAdds = static_cast<KaxReferenceBlock *>(FindNextElt(*MyBlockAdds));
-    assert(MyBlockAdds != NULL);
+    assert(MyBlockAdds != nullptr);
     Index--;
   }
   return *MyBlockAdds;
@@ -843,8 +847,8 @@ const KaxReferenceBlock & KaxBlockGroup::Reference(unsigned int Index) const
 
 void KaxBlockGroup::ReleaseFrames()
 {
-  KaxInternalBlock & MyBlock = *static_cast<KaxBlock *>(this->FindElt(EBML_INFO(KaxBlock)));
-  MyBlock.ReleaseFrames();
+  auto MyBlock = static_cast<KaxBlock *>(this->FindElt(EBML_INFO(KaxBlock)));
+  MyBlock->ReleaseFrames();
 }
 
 void KaxInternalBlock::ReleaseFrames()
@@ -852,42 +856,42 @@ void KaxInternalBlock::ReleaseFrames()
   // free the allocated Frames
   int i;
   for (i=myBuffers.size()-1; i>=0; i--) {
-    if (myBuffers[i] != NULL) {
+    if (myBuffers[i] != nullptr) {
       myBuffers[i]->FreeBuffer(*myBuffers[i]);
       delete myBuffers[i];
-      myBuffers[i] = NULL;
+      myBuffers[i] = nullptr;
     }
   }
 }
 
 void KaxBlockGroup::SetBlockDuration(uint64 TimeLength)
 {
-  assert(ParentTrack != NULL);
-  int64 scale = ParentTrack->GlobalTimecodeScale();
-  KaxBlockDuration & myDuration = *static_cast<KaxBlockDuration *>(FindFirstElt(EBML_INFO(KaxBlockDuration), true));
-  *(static_cast<EbmlUInteger *>(&myDuration)) = TimeLength / uint64(scale);
+  assert(ParentTrack != nullptr);
+  const int64 scale = ParentTrack->GlobalTimecodeScale();
+  const auto& myDuration = static_cast<KaxBlockDuration *>(FindFirstElt(EBML_INFO(KaxBlockDuration), true));
+  *(static_cast<EbmlUInteger *>(myDuration)) = TimeLength / static_cast<uint64>(scale);
 }
 
 bool KaxBlockGroup::GetBlockDuration(uint64 &TheTimecode) const
 {
-  KaxBlockDuration * myDuration = static_cast<KaxBlockDuration *>(FindElt(EBML_INFO(KaxBlockDuration)));
-  if (myDuration == NULL) {
+  auto myDuration = static_cast<KaxBlockDuration *>(FindElt(EBML_INFO(KaxBlockDuration)));
+  if (myDuration == nullptr) {
     return false;
   }
 
-  assert(ParentTrack != NULL);
-  TheTimecode = uint64(*myDuration) * ParentTrack->GlobalTimecodeScale();
+  assert(ParentTrack != nullptr);
+  TheTimecode = static_cast<uint64>(*myDuration) * ParentTrack->GlobalTimecodeScale();
   return true;
 }
 
 KaxBlockGroup::operator KaxInternalBlock &() {
-  KaxBlock & theBlock = GetChild<KaxBlock>(*this);
+  auto & theBlock = GetChild<KaxBlock>(*this);
   return theBlock;
 }
 
 void KaxBlockGroup::SetParent(KaxCluster & aParentCluster) {
   ParentCluster = &aParentCluster;
-  KaxBlock & theBlock = GetChild<KaxBlock>(*this);
+  auto & theBlock = GetChild<KaxBlock>(*this);
   theBlock.SetParent( aParentCluster );
 }
 
@@ -948,69 +952,59 @@ KaxBlockBlob::operator const KaxBlockGroup &() const
 KaxBlockBlob::operator KaxInternalBlock &()
 {
   assert(Block.group);
-#if MATROSKA_VERSION >= 2
   if (bUseSimpleBlock)
     return *Block.simpleblock;
-  else
-#endif
-    return *Block.group;
+  return *Block.group;
 }
 
 KaxBlockBlob::operator const KaxInternalBlock &() const
 {
   assert(Block.group);
-#if MATROSKA_VERSION >= 2
   if (bUseSimpleBlock)
     return *Block.simpleblock;
-  else
-#endif
-    return *Block.group;
+  return *Block.group;
 }
 
-#if MATROSKA_VERSION >= 2
 KaxBlockBlob::operator KaxSimpleBlock &()
 {
   assert(bUseSimpleBlock);
   assert(Block.simpleblock);
   return *Block.simpleblock;
 }
-#endif
 
 bool KaxBlockBlob::AddFrameAuto(const KaxTrackEntry & track, uint64 timecode, DataBuffer & buffer, LacingType lacing, const KaxBlockBlob * PastBlock, const KaxBlockBlob * ForwBlock)
 {
   bool bResult = false;
-#if MATROSKA_VERSION >= 2
-  if ((SimpleBlockMode == BLOCK_BLOB_ALWAYS_SIMPLE) || (SimpleBlockMode == BLOCK_BLOB_SIMPLE_AUTO && PastBlock == NULL && ForwBlock == NULL)) {
+  if ((SimpleBlockMode == BLOCK_BLOB_ALWAYS_SIMPLE) || (SimpleBlockMode == BLOCK_BLOB_SIMPLE_AUTO && PastBlock == nullptr && ForwBlock == nullptr)) {
     assert(bUseSimpleBlock == true);
-    if (Block.simpleblock == NULL) {
+    if (Block.simpleblock == nullptr) {
       Block.simpleblock = new KaxSimpleBlock();
       Block.simpleblock->SetParent(*ParentCluster);
     }
 
     bResult = Block.simpleblock->AddFrame(track, timecode, buffer, lacing);
-    if (PastBlock == NULL && ForwBlock == NULL) {
+    if (PastBlock == nullptr && ForwBlock == nullptr) {
       Block.simpleblock->SetKeyframe(true);
       Block.simpleblock->SetDiscardable(false);
     } else {
       Block.simpleblock->SetKeyframe(false);
-      if ((ForwBlock == NULL || ((const KaxInternalBlock &)*ForwBlock).GlobalTimecode() <= timecode) &&
-          (PastBlock == NULL || ((const KaxInternalBlock &)*PastBlock).GlobalTimecode() <= timecode))
+      if ((ForwBlock == nullptr || static_cast<const KaxInternalBlock &>(*ForwBlock).GlobalTimecode() <= timecode) &&
+          (PastBlock == nullptr || static_cast<const KaxInternalBlock &>(*PastBlock).GlobalTimecode() <= timecode))
         Block.simpleblock->SetDiscardable(false);
       else
         Block.simpleblock->SetDiscardable(true);
     }
   }
   else
-#endif
     if (ReplaceSimpleByGroup())
       bResult = Block.group->AddFrame(track, timecode, buffer, PastBlock, ForwBlock, lacing);
 
   return bResult;
 }
 
-void KaxBlockBlob::SetParent(KaxCluster & parent_clust)
+void KaxBlockBlob::SetParent(KaxCluster & aParentCluster)
 {
-  ParentCluster = &parent_clust;
+  ParentCluster = &aParentCluster;
 }
 
 void KaxBlockBlob::SetBlockDuration(uint64 TimeLength)
@@ -1025,15 +1019,14 @@ bool KaxBlockBlob::ReplaceSimpleByGroup()
     return false;
 
   if (!bUseSimpleBlock) {
-    if (Block.group == NULL) {
+    if (Block.group == nullptr) {
       Block.group = new KaxBlockGroup();
     }
   }
-#if MATROSKA_VERSION >= 2
   else {
 
-    if (Block.simpleblock != NULL) {
-      KaxSimpleBlock *old_simpleblock = Block.simpleblock;
+    if (Block.simpleblock != nullptr) {
+      KaxSimpleBlock *const old_simpleblock = Block.simpleblock;
       Block.group = new KaxBlockGroup();
       // _TODO_ : move all the data to the blockgroup
       assert(false);
@@ -1043,8 +1036,7 @@ bool KaxBlockBlob::ReplaceSimpleByGroup()
       Block.group = new KaxBlockGroup();
     }
   }
-#endif
-  if (ParentCluster != NULL)
+  if (ParentCluster != nullptr)
     Block.group->SetParent(*ParentCluster);
 
   bUseSimpleBlock = false;
@@ -1063,4 +1055,4 @@ filepos_t KaxBlockVirtual::ReadData(IOCallback & input, ScopeMode /* ReadFully *
   return GetSize();
 }
 
-END_LIBMATROSKA_NAMESPACE
+} // namespace libmatroska
