@@ -24,7 +24,7 @@ swap_buffer(uint8_t const *src,
             std::size_t num_bytes,
             std::size_t word_length) {
   if ((num_bytes % word_length) != 0)
-    throw std::invalid_argument(fmt::format(Y("The number of bytes to swap isn't divisible by {0}."), word_length));
+    throw std::invalid_argument(fmt::format(FY("The number of bytes to swap isn't divisible by {0}."), word_length));
 
   for (int idx = 0; idx < static_cast<int>(num_bytes); idx += word_length)
     put_uint_le(&dst[idx], get_uint_be(&src[idx], word_length), word_length);
