@@ -7,7 +7,7 @@
    see the file COPYING for details
    or visit https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
 
-   \author Written by Moritz Bunkus <moritz@bunkus.org>.
+   \author Written by Moritz Bunkus <mo@bunkus.online>.
 */
 
 #pragma once
