@@ -4,11 +4,11 @@
 
   Distributed under the GPL v2
   see the file COPYING for details
-  or visit http://www.gnu.org/copyleft/gpl.html
+  or visit https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
 
   EBML/XML converter specialization for segmentinfo
 
-  Written by Moritz Bunkus <moritz@bunkus.org>.
+  Written by Moritz Bunkus <mo@bunkus.online>.
 */
 
 #pragma once
