@@ -4,7 +4,7 @@
 
    Distributed under the GPL v2
    see the file COPYING for details
-   or visit http://www.gnu.org/copyleft/gpl.html
+   or visit https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
 
    class definitions for the TTA demultiplexer module
 
@@ -22,8 +22,8 @@
 class wavpack_reader_c: public generic_reader_c {
 private:
   mm_io_cptr m_in_correc;
-  wavpack_header_t header, header_correc;
-  wavpack_meta_t meta, meta_correc;
+  mtx::wavpack::header_t header, header_correc;
+  mtx::wavpack::meta_t meta, meta_correc;
 
 public:
   virtual mtx::file_type_e get_format_type() const {
@@ -40,5 +40,5 @@ public:
   virtual bool probe_file() override;
 
 protected:
-  virtual file_status_e read(generic_packetizer_c *ptzr, bool force = false) override;
+  virtual file_status_e read(generic_packetizer_c *packetizer, bool force = false) override;
 };
