@@ -327,7 +327,7 @@ Tool::tabTitleChanged() {
 
 QString
 Tool::chapterNameTemplateToolTip() {
-  return Q("<p>%1 %2 %3 %4</p><p>%5 %6</p><p>%7 %8 %9</p><ul><li>%10</li><li>%11</li><li>%12</li><li>%13</li><li>%14</li><li>%15</li><li>%16</li><li>%17</li></ul>")
+  return Q("<p>%1 %2 %3 %4</p><p>%5 %6</p><p>%7 %8 %9</p><ul><li>%10</li><li>%11</li><li>%12</li><li>%13</li><li>%14</li><li>%15</li><li>%16</li><li>%17</li><li>%18</li></ul>")
     .arg(QYH("This template will be used for new chapter entries."))
     .arg(QYH("The string '<NUM>' will be replaced by the chapter number."))
     .arg(QYH("The string '<START>' will be replaced by the chapter's start timestamp."))
@@ -349,7 +349,8 @@ Tool::chapterNameTemplateToolTip() {
     .arg(QYH("%s – seconds"))
     .arg(QYH("%S – seconds zero-padded to two places"))
     .arg(QYH("%n – nanoseconds with nine places"))
-    .arg(QYH("%<1-9>n – nanoseconds with up to nine places (e.g. three places with %3n)"))
+    .arg(QYH("%<1-9>n – nanoseconds with up to nine places (e.g. three places with %{}3n)"))
+    .remove(Q("{}"))
   + Q("<p>%1</p>")
     .arg(QYH("If nothing is entered, chapters will be generated but no name will be set."));
 }
