@@ -1,5 +1,4 @@
-#ifndef MTX_MKVTOOLNIX_GUI_HEADER_EDITOR_ASCII_STRING_VALUE_PAGE_H
-#define MTX_MKVTOOLNIX_GUI_HEADER_EDITOR_ASCII_STRING_VALUE_PAGE_H
+#pragma once
 
 #include "common/common_pch.h"
 
@@ -7,7 +6,7 @@
 
 class QLineEdit;
 
-namespace mtx { namespace gui { namespace HeaderEditor {
+namespace mtx::gui::HeaderEditor {
 
 class Tab;
 
@@ -17,7 +16,7 @@ public:
   std::string m_originalValue;
 
 public:
-  AsciiStringValuePage(Tab &parent, PageBase &topLevelPage, EbmlMaster &master, EbmlCallbacks const &callbacks, translatable_string_c const &title, translatable_string_c const &description);
+  AsciiStringValuePage(Tab &parent, PageBase &topLevelPage, libebml::EbmlMaster &master, libebml::EbmlCallbacks const &callbacks, translatable_string_c const &title, translatable_string_c const &description);
   virtual ~AsciiStringValuePage();
 
   virtual QWidget *createInputControl() override;
@@ -28,6 +27,4 @@ public:
   virtual void copyValueToElement() override;
 };
 
-}}}
-
-#endif  // MTX_MKVTOOLNIX_GUI_HEADER_EDITOR_ASCII_STRING_VALUE_PAGE_H
+}
