@@ -36,11 +36,11 @@ public:
 protected:
   virtual void setItems(QList<QStandardItem *> const &items) const override;
   virtual void summarizeProperties();
-  virtual ValuePage *findPageForElement(EbmlId const &id);
-  virtual QString getPageStringValueForElement(EbmlId const &wantedId);
-  virtual double getPageDoubleValueForElement(EbmlId const &wantedId, double valueIfNotPresent);
-  virtual uint64_t getPageUnsignedIntegerValueForElement(EbmlId const &wantedId, uint64_t valueIfNotPresent);
-  virtual bool getPageBoolValueForElement(EbmlId const &wantedId, bool valueIfNotPresent);
+  virtual ValuePage *findPageForElement(libebml::EbmlId const &id);
+  virtual QString getPageStringValueForElement(libebml::EbmlId const &wantedId);
+  virtual double getPageDoubleValueForElement(libebml::EbmlId const &wantedId, double valueIfNotPresent);
+  virtual uint64_t getPageUnsignedIntegerValueForElement(libebml::EbmlId const &wantedId, uint64_t valueIfNotPresent);
+  virtual bool getPageBoolValueForElement(libebml::EbmlId const &wantedId, bool valueIfNotPresent);
 
 public Q_SLOTS:
   virtual void retranslateUi() override;
