@@ -36,7 +36,7 @@ QString
 sanitizeDirectory(QString const &directory,
                   bool withFileName) {
   auto dir     = to_utf8(directory.isEmpty() || (directory == Q(".")) ? QStandardPaths::writableLocation(QStandardPaths::MoviesLocation) : directory);
-  auto oldPath = mtx::fs::absolute(mtx::fs::to_path(dir));
+  auto oldPath = boost::filesystem::absolute(mtx::fs::to_path(dir));
   auto newPath = oldPath;
   auto ec      = boost::system::error_code{};
 
