@@ -303,10 +303,6 @@ void QgsCollapsibleGroupBoxBasic::toggleCollapsed()
 
 void QgsCollapsibleGroupBoxBasic::setStyleSheet( const QString &style )
 {
-#if QT_VERSION < QT_VERSION_CHECK(5, 12, 4)
-  // Fix crash on old Qt versions, see #39693
-  QGroupBox::setStyleSheet( QString() );
-#endif
   QGroupBox::setStyleSheet( style );
 }
 
