@@ -8,7 +8,7 @@
 
    AAC output module
 
-   Written by Moritz Bunkus <moritz@bunkus.org>.
+   Written by Moritz Bunkus <mo@bunkus.online>.
 */
 
 #include "common/common_pch.h"
@@ -120,7 +120,7 @@ aac_packetizer_c::process_impl(packet_cptr const &packet) {
     process_headerless(std::make_shared<packet_t>(frame.m_data));
 
     if (verbose && frame.m_garbage_size)
-      mxwarn_tid(m_ti.m_fname, m_ti.m_id, fmt::format(Y("Skipping {0} bytes (no valid AAC header found). This might cause audio/video desynchronisation.\n"), frame.m_garbage_size));
+      mxwarn_tid(m_ti.m_fname, m_ti.m_id, fmt::format(FY("Skipping {0} bytes (no valid AAC header found). This might cause audio/video desynchronisation.\n"), frame.m_garbage_size));
   }
 }
 
@@ -134,7 +134,7 @@ aac_packetizer_c::can_connect_to(generic_packetizer_c *src,
   connect_check_a_samplerate(m_config.sample_rate, asrc->m_config.sample_rate);
   connect_check_a_channels(m_config.channels, asrc->m_config.channels);
   if (m_config.profile != asrc->m_config.profile) {
-    error_message = fmt::format(Y("The AAC profiles are different: {0} and {1}"), m_config.profile, asrc->m_config.profile);
+    error_message = fmt::format(FY("The AAC profiles are different: {0} and {1}"), m_config.profile, asrc->m_config.profile);
     return CAN_CONNECT_NO_PARAMETERS;
   }
 
