@@ -8,7 +8,7 @@ nn   see the file COPYING for details
 
    Dirac video output module
 
-   Written by Moritz Bunkus <moritz@bunkus.org>.
+   Written by Moritz Bunkus <mo@bunkus.online>.
 */
 
 #include "common/common_pch.h"
@@ -22,8 +22,6 @@ nn   see the file COPYING for details
 #include "merge/output_control.h"
 #include "output/p_dirac.h"
 
-using namespace libmatroska;
-
 dirac_video_packetizer_c::dirac_video_packetizer_c(generic_reader_c *p_reader, track_info_c &p_ti)
   : generic_packetizer_c{p_reader, p_ti, track_video}
   , m_headers_found(false)
@@ -51,7 +49,7 @@ dirac_video_packetizer_c::set_headers() {
         display_height = std::llround(display_height * m_seqhdr.aspect_ratio_denominator / m_seqhdr.aspect_ratio_numerator);
     }
 
-    set_video_display_dimensions(display_width, display_height, generic_packetizer_c::ddu_pixels, OPTION_SOURCE_BITSTREAM);
+    set_video_display_dimensions(display_width, display_height, generic_packetizer_c::ddu_pixels, option_source_e::bitstream);
 
     if (m_default_duration_forced)
       m_parser.set_default_duration(get_track_default_duration());
