@@ -9,12 +9,11 @@
    VobBtn packetizer
 
    Written by Steve Lhomme <steve.lhomme@free.fr>.
-   Modified by Moritz Bunkus <moritz@bunkus.org>.
+   Modified by Moritz Bunkus <mo@bunkus.online>.
 */
 
 #include "common/common_pch.h"
 
-#include <matroska/KaxContentEncoding.h>
 #include <matroska/KaxTracks.h>
 
 #include "common/codec.h"
@@ -23,8 +22,6 @@
 #include "merge/connection_checks.h"
 #include "output/p_vobbtn.h"
 
-using namespace libmatroska;
-
 vobbtn_packetizer_c::vobbtn_packetizer_c(generic_reader_c *p_reader,
                                          track_info_c &p_ti,
                                          int width,
