@@ -24,15 +24,18 @@ private:
   int64_t m_samples_per_block;
   int64_t m_samples_output;
   bool m_has_correction;
+  mtx_mp_rational_t m_sample_duration;
 
 public:
   wavpack_packetizer_c(generic_reader_c *p_reader, track_info_c &p_ti, mtx::wavpack::meta_t &meta);
 
-  virtual int process(packet_cptr packet);
   virtual void set_headers();
 
   virtual translatable_string_c get_format_name() const {
     return YT("WAVPACK4");
   }
   virtual connection_result_e can_connect_to(generic_packetizer_c *src, std::string &error_message);
+
+protected:
+  virtual void process_impl(packet_cptr const &packet) override;
 };
