@@ -5,7 +5,7 @@
    see the file COPYING for details
    or visit https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
 
-   Written by Moritz Bunkus <moritz@bunkus.org>.
+   Written by Moritz Bunkus <mo@bunkus.online>.
 */
 
 #pragma once
@@ -16,8 +16,6 @@
 
 #include "propedit/change.h"
 
-#define INVALID_TRACK_TYPE static_cast<track_type>(0)
-
 class kax_analyzer_c;
 
 class target_c {
