@@ -1,8 +1,10 @@
 #include "common/common_pch.h"
 
+#include <functional>
+
 #include "common/list_utils.h"
 
-#include "gtest/gtest.h"
+#include "tests/unit/init.h"
 
 namespace {
 
