@@ -15,63 +15,63 @@ TEST(OptionWithSource, CreationWithoutValue) {
 }
 
 TEST(OptionWithSource, CreationWithValue) {
-  option_with_source_c<int64_t> o(42, OPTION_SOURCE_CONTAINER);
+  option_with_source_c<int64_t> o(42, option_source_e::container);
 
   ASSERT_EQ(static_cast<bool>(o), true);
   ASSERT_EQ(o.get(),              42);
-  ASSERT_EQ(o.get_source(),       OPTION_SOURCE_CONTAINER);
+  ASSERT_EQ(o.get_source(),       option_source_e::container);
 }
 
 TEST(OptionWithSource, SetValueOnce) {
   option_with_source_c<int64_t> o;
 
   ASSERT_EQ(static_cast<bool>(o), false);
-  o.set(42, OPTION_SOURCE_CONTAINER);
+  o.set(42, option_source_e::container);
   ASSERT_EQ(static_cast<bool>(o), true);
   ASSERT_EQ(o.get(),              42);
-  ASSERT_EQ(o.get_source(),       OPTION_SOURCE_CONTAINER);
+  ASSERT_EQ(o.get_source(),       option_source_e::container);
 }
 
 TEST(OptionWithSource, SetValueLowerSource) {
   option_with_source_c<int64_t> o;
 
   ASSERT_EQ(static_cast<bool>(o), false);
-  o.set(42, OPTION_SOURCE_CONTAINER);
+  o.set(42, option_source_e::container);
   ASSERT_EQ(static_cast<bool>(o), true);
   ASSERT_EQ(o.get(),              42);
-  ASSERT_EQ(o.get_source(),       OPTION_SOURCE_CONTAINER);
-  o.set(54, OPTION_SOURCE_BITSTREAM);
+  ASSERT_EQ(o.get_source(),       option_source_e::container);
+  o.set(54, option_source_e::bitstream);
   ASSERT_EQ(static_cast<bool>(o), true);
   ASSERT_EQ(o.get(),              42);
-  ASSERT_EQ(o.get_source(),       OPTION_SOURCE_CONTAINER);
+  ASSERT_EQ(o.get_source(),       option_source_e::container);
 }
 
 TEST(OptionWithSource, SetValueSameSource) {
   option_with_source_c<int64_t> o;
 
   ASSERT_EQ(static_cast<bool>(o), false);
-  o.set(42, OPTION_SOURCE_CONTAINER);
+  o.set(42, option_source_e::container);
   ASSERT_EQ(static_cast<bool>(o), true);
   ASSERT_EQ(o.get(),              42);
-  ASSERT_EQ(o.get_source(),       OPTION_SOURCE_CONTAINER);
-  o.set(54, OPTION_SOURCE_CONTAINER);
+  ASSERT_EQ(o.get_source(),       option_source_e::container);
+  o.set(54, option_source_e::container);
   ASSERT_EQ(static_cast<bool>(o), true);
   ASSERT_EQ(o.get(),              54);
-  ASSERT_EQ(o.get_source(),       OPTION_SOURCE_CONTAINER);
+  ASSERT_EQ(o.get_source(),       option_source_e::container);
 }
 
 TEST(OptionWithSource, SetValueHigherSource) {
   option_with_source_c<int64_t> o;
 
   ASSERT_EQ(static_cast<bool>(o), false);
-  o.set(42, OPTION_SOURCE_CONTAINER);
+  o.set(42, option_source_e::container);
   ASSERT_EQ(static_cast<bool>(o), true);
   ASSERT_EQ(o.get(),              42);
-  ASSERT_EQ(o.get_source(),       OPTION_SOURCE_CONTAINER);
-  o.set(54, OPTION_SOURCE_COMMAND_LINE);
+  ASSERT_EQ(o.get_source(),       option_source_e::container);
+  o.set(54, option_source_e::command_line);
   ASSERT_EQ(static_cast<bool>(o), true);
   ASSERT_EQ(o.get(),              54);
-  ASSERT_EQ(o.get_source(),       OPTION_SOURCE_COMMAND_LINE);
+  ASSERT_EQ(o.get_source(),       option_source_e::command_line);
 }
 
 }
